# -*- rpm-spec -*-

# This spec file assumes you are building on a Fedora or RHEL version
# that's still supported by the vendor. It may work on other distros
# or versions, but no effort will be made to ensure that going forward
%define min_rhel 7
%define min_fedora 29

%if (0%{?fedora} && 0%{?fedora} >= %{min_fedora}) || (0%{?rhel} && 0%{?rhel} >= %{min_rhel})
    %define supported_platform 1
%else
    %define supported_platform 0
%endif

Summary: The libvirt virtualization API python3 binding
Name: libvirt-python
Version: 6.6.0
Release: 2%{?dist}.4
Source0: %{name}-%{version}.tar.gz

# Vz patches
Patch10000: 10000-Add-pull-backup-API.patch
Patch10001: 10001-Add-IO-latency-API.patch
Patch10002: 10002-Add-stub-for-VIR_DOMAIN_EVENT_ID_BLOCK_JOB_ERROR_X-.patch
Patch10003: 10003-add-exec-API-PSBM-106198.patch
Patch10004: 10004-bring-python2-support-back-PSBM-131673.patch
Patch10005: 10005-add-domain.setGuestNetworkParameters-API-PSBM-13559.patch
Patch10006: 10006-Add-stub-for-VIR_DOMAIN_EVENT_ID_TUNE_GUEST_X-event.patch
Patch10007: 10007-FIXUP-add-domain.setGuestNetworkParameters-API.patch
Url: http://libvirt.org
License: LGPLv2+
ExclusiveArch: x86_64
BuildRequires: git
BuildRequires: libvirt-devel >= 6.6.0-13
BuildRequires: python3-devel
%if 0%{?rhel} == 7
BuildRequires: python36-nose
BuildRequires: python36-lxml
BuildRequires: python-devel
BuildRequires: python-nose
%else
BuildRequires: python3-nose
BuildRequires: python3-lxml
BuildRequires: python2-devel
BuildRequires: python2-nose
%endif
BuildRequires: gcc

# Don't want provides for python shared objects
%{?filter_provides_in: %filter_provides_in %{python2_sitearch}/.*\.so}
%{?filter_provides_in: %filter_provides_in %{python3_sitearch}/.*\.so}
%{?filter_setup}

%description
The libvirt-python package contains a module that permits applications
written in the Python programming language to use the interface
supplied by the libvirt library to use the virtualization capabilities
of recent versions of Linux (and other OSes).

%package -n python3-libvirt
Summary: The libvirt virtualization API python3 binding
Url: http://libvirt.org
License: LGPLv2+
#%{?python_provide:%python_provide python3-libvirt}
Provides: libvirt-python3 = %{version}-%{release}
Obsoletes: libvirt-python3 <= 3.6.0-1%{?dist}
Obsoletes: libvirt-python <= 5.6.0-2%{?dist}

%description -n python3-libvirt
The python3-libvirt package contains a module that permits applications
written in the Python 3.x programming language to use the interface
supplied by the libvirt library to use the virtualization capabilities
of recent versions of Linux (and other OSes).

%package -n python2-libvirt
Summary: The libvirt virtualization API python2 binding
Url: http://libvirt.org
License: LGPLv2+
#%{?python_provide:%python_provide python2-libvirt}
Provides: libvirt-python = %{version}-%{release}
Obsoletes: libvirt-python < 5.6.0-2%{?dist}

%description -n python2-libvirt
The python2-libvirt package contains a module that permits applications
written in the Python programming language to use the interface
supplied by the libvirt library to use the virtualization capabilities
of recent versions of Linux (and other OSes).

%prep
%autosetup -S git_am -N

git config gc.auto 0

%autopatch


# Unset execute bit for example scripts; it can introduce spurious
# RPM dependencies, like /usr/bin/python3
# for the -python3 package
find examples -type f -exec chmod 0644 \{\} \;

%build
%if ! %{supported_platform}
echo "This RPM requires either Fedora >= %{min_fedora} or RHEL >= %{min_rhel}"
exit 1
%endif

%if 0%{?fedora} || 0%{?rhel} >= 8
%py3_build
%py2_build
%else
CFLAGS="$RPM_OPT_FLAGS" %{__python3} setup.py build
CFLAGS="$RPM_OPT_FLAGS" %{__python2} setup.py build
%endif

%install
%if 0%{?fedora} || 0%{?rhel} >= 8
%py3_install
%py2_install
%else
%{__python3} setup.py install --skip-build --root=%{buildroot}
%{__python2} setup.py install --skip-build --root=%{buildroot}
%endif

%check
%{__python3} setup.py test

%files -n python3-libvirt
%doc ChangeLog AUTHORS README COPYING COPYING.LESSER examples/
%{python3_sitearch}/libvirt.py*
%{python3_sitearch}/libvirtaio.py*
%{python3_sitearch}/libvirt_qemu.py*
%{python3_sitearch}/libvirt_lxc.py*
%{python3_sitearch}/__pycache__/libvirt.cpython-*.py*
%{python3_sitearch}/__pycache__/libvirt_qemu.cpython-*.py*
%{python3_sitearch}/__pycache__/libvirt_lxc.cpython-*.py*
%{python3_sitearch}/__pycache__/libvirtaio.cpython-*.py*
%{python3_sitearch}/libvirtmod*
%{python3_sitearch}/*egg-info

%files -n python2-libvirt
%doc ChangeLog AUTHORS README COPYING COPYING.LESSER examples/
%{python2_sitearch}/libvirt.py*
%{python2_sitearch}/libvirt_qemu.py*
%{python2_sitearch}/libvirt_lxc.py*
%{python2_sitearch}/libvirtmod*
%{python2_sitearch}/*egg-info

%changelog
* Mon Nov 08 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-6.6.0-2.vz8.4
- FIXUP: add domain.setGuestNetworkParameters API

* Mon Nov 08 2021 Nikolay Shirokovskiy <nshirokovskiy@virtuozzo.com> - vz-6.6.0-2.vz8.3
- add domain.setGuestNetworkParameters API #PSBM-135597
- Add stub for VIR_DOMAIN_EVENT_ID_TUNE_GUEST_X event

* Tue Jul 13 2021 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-6.6.0-2.vz8.2
- bring python2 support back #PSBM-131673

* Thu Jul 01 2021 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-6.6.0-2.vz8.1
- Add pull backup API
- Add IO latency API
- Add stub for VIR_DOMAIN_EVENT_ID_BLOCK_JOB_ERROR_X event
- add exec API #PSBM-106198

* Thu Feb  4 2021 Jiri Denemark <jdenemar@redhat.com> - 6.6.0-2
- [incremental backup] python3-libvirt is missing newly added constants for incremental backup (rhbz#1924705)

* Wed Aug  5 2020 Jiri Denemark <jdenemar@redhat.com> - 6.6.0-1
- Rebased to libvirt-python-6.6.0 (rhbz#1809686)

* Mon Jul 13 2020 Jiri Denemark <jdenemar@redhat.com> - 6.5.0-1
- Rebased to libvirt-python-6.5.0 (rhbz#1809686)

* Wed Jun  3 2020 Jiri Denemark <jdenemar@redhat.com> - 6.4.0-1
- Rebased to libvirt-python-6.4.0 (rhbz#1809686)

* Tue May  5 2020 Jiri Denemark <jdenemar@redhat.com> - 6.3.0-1
- Rebased to libvirt-python-6.3.0 (rhbz#1809686)

* Mon Apr 20 2020 Jiri Denemark <jdenemar@redhat.com> - 6.2.0-1
- Rebased to libvirt-python-6.2.0 (rhbz#1809686)

* Wed Jan 15 2020 Jiri Denemark <jdenemar@redhat.com> - 6.0.0-1
- Rebased to libvirt-python-6.0.0 (rhbz#1772046)
- The rebase also fixes the following bugs:
    rhbz#1786968, rhbz#1786980

* Tue Dec 10 2019 Jiri Denemark <jdenemar@redhat.com> - 5.10.0-1
- Rebased to libvirt-python-5.10.0 (rhbz#1772046)

* Thu Nov 14 2019 Jiri Denemark <jdenemar@redhat.com> - 5.9.0-1
- Rebased to libvirt-python-5.9.0 (rhbz#1772046)
- The rebase also fixes the following bugs:
    rhbz#1750677

* Wed Sep 25 2019 Jiri Denemark <jdenemar@redhat.com> - 5.6.0-2
- virDomainMemoryStats: include disk caches (rhbz#1683516)
- virDomainMemoryStats: include hugetlb pgalloc and pgfail (rhbz#1683516)
- virDomainMigrate3Params: add missing bandwidth postcopy param (rhbz#1754466)
- virDomainMigrate3Params: add missing parallel connections param (rhbz#1754466)

* Tue Aug  6 2019 Jiri Denemark <jdenemar@redhat.com> - 5.6.0-1
- Rebased to libvirt-python-5.6.0 (rhbz#1705224)

* Thu Jul  4 2019 Jiri Denemark <jdenemar@redhat.com> - 5.5.0-1
- Rebased to libvirt-python-5.5.0 (rhbz#1705224)

* Mon Jul 01 2019 Danilo de Paula <ddepaula@redhat.com>
- Rebuild all virt packages to fix RHEL's upgrade path
- Resolves: rhbz#1725216
  (Ensure modular RPM upgrade path [rhel-av-8.1.0])

* Tue Jun  4 2019 Jiri Denemark <jdenemar@redhat.com> - 5.4.0-1
- Rebased to libvirt-python-5.4.0 (rhbz#1705224)

* Tue May  7 2019 Jiri Denemark <jdenemar@redhat.com> - 5.3.0-1
- Rebased to libvirt-python-5.3.0 (rhbz#1705224)

* Wed Feb 27 2019 Jiri Denemark <jdenemar@redhat.com> - 5.0.0-3
- Fix virDomainPinIOThread typed params check (rhbz#1680546)

* Fri Feb  8 2019 Jiri Denemark <jdenemar@redhat.com> - 5.0.0-2
- Rebuild for post-copy migration bandwidth (rhbz#1673043)

* Tue Jan 29 2019 Jiri Denemark <jdenemar@redhat.com> - 5.0.0-1
- Rebased to libvirt-python-5.0.0 (rhbz#1666122)

* Fri Dec  7 2018 Jiri Denemark <jdenemar@redhat.com> - 4.10.0-1
- Rebased to libvirt-python-4.10.0

* Tue Jul  3 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-1
- Rebased to libvirt-python-4.5.0

* Fri May 25 2018 Jiri Denemark <jdenemar@redhat.com> - 4.3.0-1
- Rebased to libvirt-python-4.3.0

* Mon Mar  5 2018 Daniel P. Berrange <berrange@redhat.com> - 4.1.0-1
- Update to 4.1.0 release

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 4.0.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Fri Jan 19 2018 Daniel P. Berrange <berrange@redhat.com> - 4.0.0-1
- Update to 4.0.0 release

* Tue Dec  5 2017 Daniel P. Berrange <berrange@redhat.com> - 3.10.0-1
- Update to 3.10.0 release

* Fri Nov  3 2017 Daniel P. Berrange <berrange@redhat.com> - 3.9.0-1
- Update to 3.9.0 release

* Wed Oct  4 2017 Daniel P. Berrange <berrange@redhat.com> - 3.8.0-1
- Update to 3.8.0 release

* Mon Sep  4 2017 Daniel P. Berrange <berrange@redhat.com> - 3.7.0-1
- Update to 3.7.0 release

* Fri Aug 11 2017 Daniel P. Berrange <berrange@redhat.com> - 3.6.0-2
- Rename sub-RPMs to python2-libvirt & python3-libvirt
- Re-add py3 conditionals for benefit of RHEL/CentOS builds

* Thu Aug 10 2017 Daniel P. Berrange <berrange@redhat.com> - 3.6.0-1
- Update to 3.6.0 release
- Always build py3 package

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.5.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.5.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Jul 07 2017 Igor Gnatenko <ignatenko@redhat.com> - 3.5.0-2
- Rebuild due to bug in RPM (RHBZ #1468476)

* Thu Jul  6 2017 Daniel P. Berrange <berrange@redhat.com> - 3.5.0-1
- Update to 3.5.0 release

* Mon Jun  5 2017 Daniel P. Berrange <berrange@redhat.com> - 3.4.0-1
- Update to 3.4.0 release

* Mon May  8 2017 Daniel P. Berrange <berrange@redhat.com> - 3.3.0-1
- Update to 3.3.0 release

* Mon Apr  3 2017 Daniel P. Berrange <berrange@redhat.com> - 3.2.0-1
- Update to 3.2.0 release

* Fri Mar  3 2017 Daniel P. Berrange <berrange@redhat.com> - 3.1.0-1
- Update to 3.1.0 release

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.0.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Jan 19 2017 Daniel P. Berrange <berrange@redhat.com> - 3.0.0-1
- Update to 3.0.0 release
